summaryrefslogtreecommitdiffstats
path: root/kimgio/ico.h
diff options
context:
space:
mode:
Diffstat (limited to 'kimgio/ico.h')
-rw-r--r--kimgio/ico.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kimgio/ico.h b/kimgio/ico.h
index 4492d4d9d..335cc8237 100644
--- a/kimgio/ico.h
+++ b/kimgio/ico.h
@@ -8,7 +8,7 @@
*
*/
// You can use QImageIO::setParameters() to request a specific
// Icon out of an .ico file:
//
// Options consist of a name=value pair and are separated by a semicolon.
@@ -39,8 +39,8 @@ class QImageIO;
extern "C"
{
- void kimgio_ico_read(QImageIO *);
-// void kimgio_ico_write(QImageIO *);
+ void kimgio_ico_read(TQImageIO *);
+// void kimgio_ico_write(TQImageIO *);
}
#endif
@@ -8,7 +8,7 @@
*
*/
-// You can use QImageIO::setParameters() to request a specific
+// You can use TQImageIO::setParameters() to request a specific
// Icon out of an .ico file:
//